@@ -21,7 +21,7 @@
 #ifndef _LIBICONV_H
 #define _LIBICONV_H
 
-#ifdef __FreeBSD__
+#ifdef __APPLE__
 #define LIBICONV_PLUG
 #endif
 
@@ -99,7 +99,7 @@ extern size_t iconv (iconv_t cd, const char* * inbuf, size_t *inbytesleft, char*
 extern int iconv_close (iconv_t cd);
 
 
-#if !defined(LIBICONV_PLUG) || defined(__FreeBSD__)
+#if !defined(LIBICONV_PLUG) || defined(__APPLE__)
 
 /* Nonstandard extensions. */
 
